##  Notifications
You receive notifications when you are added or removed as a subscriber to a fact sheet and when the quality seal is broken due to another user updating your fact sheet where you are subscribed as Responsible or Accountable.
These notifications are accessible through all channels configured in your notification settings. Notifications aim to ensure engagement, especially from stakeholders who do not regularly use SAP LeanIX as their primary tool.
You can change your notification settings and frequency by navigating to Notifications under My settings and selecting Subscriptions. To change the notification settings for changes in the quality seal, select Data Quality. To learn more about notifications, see [Notifications](https://help.sap.com/docs/leanix/ea/notifications?locale=en-US&state=PRODUCTION&version=CLOUD "Adjust your notification preferences to stay informed about significant changes in your workspace, monitor tasks that need your attention, and stay updated on other relevant activities.").
